"""
Copyright © 2022 Gaspard d'Hautefeuille

This file is part of automx3.

automx3 is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

automx3 is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with automx3. If not, see <https://www.gnu.org/licenses/>.
"""
from flask import abort
from flask import request
from flask.views import MethodView

from automx3 import AutomxException
from automx3 import NotFoundException
from automx3 import log
from automx3.generators.mozilla import MozillaGenerator
from automx3.views import EMAIL_MOZILLA
from automx3.views import MailConfig


class MozillaView(MailConfig, MethodView):
    """Autoconfigure mail, Mozilla-style."""

    def get(self):
        """GET request is expected to contain ?emailaddress=user@example.com"""
        address = request.args.get(EMAIL_MOZILLA, '')
        if not address:
            message = f'Missing request argument "{EMAIL_MOZILLA}"'
            log.error(message)
            return message, 400
        try:
            return self.config_from_address(address)
        except NotFoundException:
            return '', 204
        except AutomxException as e:
            log.exception(e)
            abort(400)

    def config_response(self, local_part, domain_part: str, realname: str, password: str) -> str:
        data = MozillaGenerator().client_config(local_part, domain_part, realname)
        return data
